@@ -44,7 +44,7 @@ from collections import OrderedDict
 
 from rcsb.db.define.DataTypeApiProvider import DataTypeApiProvider
 from rcsb.db.define.ContentDefinition import ContentDefinition
-from rcsb.db.define.DictionaryApiProviderWrapper import DictionaryApiProviderWrapper
+from rcsb.utils.dictionary.DictionaryApiProviderWrapper import DictionaryApiProviderWrapper
 
 logger = logging.getLogger(__name__)
 
@@ -65,9 +65,7 @@ class SchemaDefBuild(object):
         self.__cfgOb = cfgOb
         self.__databaseName = databaseName
         self.__cachePath = cachePath if cachePath else "."
-        self.__includeContentClasses = (
-            includeContentClasses if includeContentClasses else ["GENERATED_CONTENT", "EVOLVING_CONTENT", "CONSOLIDATED_BIRD_CONTENT", "INTEGRATED_CONTENT"]
-        )
+        self.__includeContentClasses = includeContentClasses if includeContentClasses else ["GENERATED_CONTENT", "EVOLVING_CONTENT", "CONSOLIDATED_BIRD_CONTENT", "INTEGRATED_CONTENT"]
         #
         self.__contentDefHelper = self.__cfgOb.getHelper("CONTENT_DEF_HELPER_MODULE", sectionName=configName, cfgOb=self.__cfgOb)
         self.__documentDefHelper = self.__cfgOb.getHelper("DOCUMENT_DEF_HELPER_MODULE", sectionName=configName, cfgOb=self.__cfgOb)
@@ -804,9 +802,7 @@ class SchemaDefBuild(object):
                                                 {"category_name": tD["CONTEXT_NAME"], "category_path": tD["FIRST_CONTEXT_PATH"], "context_attributes": vvDL}
                                             ]
                                         else:
-                                            subCatPropD[subCategory]["rcsb_nested_indexing_context"] = [
-                                                {"category_name": tD["CONTEXT_NAME"], "category_path": tD["FIRST_CONTEXT_PATH"]}
-                                            ]
+                                            subCatPropD[subCategory]["rcsb_nested_indexing_context"] = [{"category_name": tD["CONTEXT_NAME"], "category_path": tD["FIRST_CONTEXT_PATH"]}]
                                     else:
                                         subCatPropD[subCategory]["rcsb_nested_indexing"] = True
             #
